@@ -6,12 +6,14 @@ plugins {
 
 dependencies {
     api(projects.backend.api)
+    implementation(projects.core.common)
 
     api(libs.okhttp)
     implementation(libs.jmap.client)
     implementation(libs.moshi)
     ksp(libs.moshi.kotlin.codegen)
 
+    testImplementation(projects.core.logging.testing)
     testImplementation(projects.mail.testing)
     testImplementation(projects.backend.testing)
     testImplementation(libs.okhttp.mockwebserver)
