@@ -2,11 +2,14 @@ package app.k9mail.core.android.common
 
 import app.k9mail.core.android.common.camera.cameraModule
 import app.k9mail.core.android.common.contact.contactModule
-import app.k9mail.core.common.coreCommonModule
+import net.thunderbird.core.android.common.resources.resourcesAndroidModule
+import net.thunderbird.core.common.coreCommonModule
 import org.koin.core.module.Module
 import org.koin.dsl.module
 
 val coreCommonAndroidModule: Module = module {
+    includes(resourcesAndroidModule)
+
     includes(coreCommonModule)
 
     includes(contactModule)
