@@ -7,11 +7,13 @@ import androidx.compose.runtime.Composable
 import androidx.compose.ui.Modifier
 import kotlinx.collections.immutable.ImmutableList
 import net.thunderbird.core.ui.compose.preference.api.Preference
+import net.thunderbird.core.ui.compose.preference.api.PreferenceSetting
 
 @Composable
 internal fun PreferenceList(
     preferences: ImmutableList<Preference>,
     onItemClick: (index: Int, item: Preference) -> Unit,
+    onPreferenceChange: (PreferenceSetting<*>) -> Unit,
     modifier: Modifier = Modifier,
 ) {
     LazyColumn(
@@ -23,6 +25,7 @@ internal fun PreferenceList(
                 onClick = {
                     onItemClick(index, item)
                 },
+                onPreferenceChange = onPreferenceChange,
                 modifier = Modifier.fillMaxWidth(),
             )
         }
