@@ -2,10 +2,10 @@ package net.thunderbird.feature.account.core.data
 
 import kotlinx.coroutines.flow.Flow
 import kotlinx.coroutines.flow.distinctUntilChanged
-import net.thunderbird.feature.account.api.AccountId
-import net.thunderbird.feature.account.api.profile.AccountProfile
-import net.thunderbird.feature.account.api.profile.AccountProfileRepository
+import net.thunderbird.feature.account.AccountId
 import net.thunderbird.feature.account.core.AccountCoreExternalContract.AccountProfileLocalDataSource
+import net.thunderbird.feature.account.profile.AccountProfile
+import net.thunderbird.feature.account.profile.AccountProfileRepository
 
 class DefaultAccountProfileRepository(
     private val localDataSource: AccountProfileLocalDataSource,
