@@ -1,8 +1,8 @@
 package app.k9mail.feature.account.setup.domain.usecase
 
-import app.k9mail.core.common.domain.usecase.validation.ValidationError
-import app.k9mail.core.common.domain.usecase.validation.ValidationResult
 import app.k9mail.feature.account.setup.domain.DomainContract
+import net.thunderbird.core.common.domain.usecase.validation.ValidationError
+import net.thunderbird.core.common.domain.usecase.validation.ValidationResult
 
 internal class ValidateAccountName : DomainContract.UseCase.ValidateAccountName {
     override fun execute(accountName: String): ValidationResult {
