@@ -1,18 +1,18 @@
 package net.thunderbird.feature.navigation.drawer.dropdown.data
 
-import app.k9mail.legacy.account.LegacyAccount
 import app.k9mail.legacy.message.controller.MessageCounts
 import app.k9mail.legacy.message.controller.MessageCountsProvider
 import kotlinx.coroutines.flow.Flow
 import kotlinx.coroutines.flow.flowOf
-import net.thunderbird.feature.search.LocalSearch
+import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.feature.search.LocalMessageSearch
 import net.thunderbird.feature.search.SearchAccount
 
 internal class FakeMessageCountsProvider(
     private val messageCounts: MessageCounts,
 ) : MessageCountsProvider {
-    var recordedSearch: LocalSearch =
-        LocalSearch()
+    var recordedSearch: LocalMessageSearch =
+        LocalMessageSearch()
 
     override fun getMessageCounts(account: LegacyAccount): MessageCounts {
         TODO("Not yet implemented")
@@ -22,11 +22,11 @@ internal class FakeMessageCountsProvider(
         TODO("Not yet implemented")
     }
 
-    override fun getMessageCounts(search: LocalSearch): MessageCounts {
+    override fun getMessageCounts(search: LocalMessageSearch): MessageCounts {
         TODO("Not yet implemented")
     }
 
-    override fun getMessageCountsFlow(search: LocalSearch): Flow<MessageCounts> {
+    override fun getMessageCountsFlow(search: LocalMessageSearch): Flow<MessageCounts> {
         recordedSearch = search
         return flowOf(messageCounts)
     }
