@@ -1,8 +1,5 @@
 package net.thunderbird.feature.navigation.drawer.dropdown.ui
 
-import app.k9mail.core.mail.folder.api.Folder
-import app.k9mail.core.mail.folder.api.FolderType
-import app.k9mail.core.ui.compose.testing.MainDispatcherRule
 import app.k9mail.core.ui.compose.testing.mvi.advanceUntilIdle
 import app.k9mail.core.ui.compose.testing.mvi.assertThatAndEffectTurbineConsumed
 import app.k9mail.core.ui.compose.testing.mvi.runMviTest
@@ -21,18 +18,21 @@ import kotlinx.coroutines.flow.flowOf
 import kotlinx.coroutines.flow.map
 import kotlinx.coroutines.test.advanceUntilIdle
 import kotlinx.coroutines.test.runTest
+import net.thunderbird.core.testing.coroutines.MainDispatcherRule
+import net.thunderbird.feature.mail.folder.api.Folder
+import net.thunderbird.feature.mail.folder.api.FolderType
 import net.thunderbird.feature.navigation.drawer.api.NavigationDrawerExternalContract.DrawerConfig
 import net.thunderbird.feature.navigation.drawer.dropdown.domain.DomainContract.UseCase
-import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.DisplayAccount
-import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.DisplayAccountFolder
 import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.DisplayFolder
 import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.DisplayTreeFolder
-import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.DisplayUnifiedFolder
-import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.DisplayUnifiedFolderType
+import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.MailDisplayAccount
+import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.MailDisplayFolder
+import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.UnifiedDisplayFolder
+import net.thunderbird.feature.navigation.drawer.dropdown.domain.entity.UnifiedDisplayFolderType
 import net.thunderbird.feature.navigation.drawer.dropdown.ui.DrawerContract.Effect
 import net.thunderbird.feature.navigation.drawer.dropdown.ui.DrawerContract.Event
 import net.thunderbird.feature.navigation.drawer.dropdown.ui.DrawerContract.State
-import net.thunderbird.feature.navigation.drawer.dropdown.ui.FakeData.DISPLAY_ACCOUNT
+import net.thunderbird.feature.navigation.drawer.dropdown.ui.FakeData.MAIL_DISPLAY_ACCOUNT
 import org.junit.Rule
 import org.mockito.Mockito.mock
 import org.mockito.Mockito.times
@@ -71,12 +71,12 @@ internal class DrawerViewModelTest {
     @Test
     fun `should change loading state when OnSyncAccount event is received`() = runMviTest {
         val initialState = State(
-            accounts = listOf(DISPLAY_ACCOUNT).toImmutableList(),
-            selectedAccountId = DISPLAY_ACCOUNT.id,
+            accounts = listOf(MAIL_DISPLAY_ACCOUNT).toImmutableList(),
+            selectedAccountId = MAIL_DISPLAY_ACCOUNT.id,
         )
         val testSubject = createTestSubject(
             initialState = initialState,
-            displayAccountsFlow = flow { emit(listOf(DISPLAY_ACCOUNT)) },
+            displayAccountsFlow = flow { emit(listOf(MAIL_DISPLAY_ACCOUNT)) },
             syncAccountFlow = flow {
                 delay(25)
                 emit(Result.success(Unit))
@@ -220,7 +220,7 @@ internal class DrawerViewModelTest {
 
     @Test
     fun `should set selected account to null when no accounts are present`() = runTest {
-        val getDisplayAccountsFlow = MutableStateFlow(emptyList<DisplayAccount>())
+        val getDisplayAccountsFlow = MutableStateFlow(emptyList<MailDisplayAccount>())
         val testSubject = createTestSubject(
             displayAccountsFlow = getDisplayAccountsFlow,
         )
@@ -316,6 +316,7 @@ internal class DrawerViewModelTest {
             selectedAccountId = displayAccounts[0].id,
             folders = displayFoldersMap[displayAccounts[0].id]!!.toImmutableList(),
             selectedFolderId = displayFoldersMap[displayAccounts[0].id]!![0].id,
+            selectedFolder = displayFoldersMap[displayAccounts[0].id]!![0],
         )
         val testSubject = createTestSubject(
             displayAccountsFlow = getDisplayAccountsFlow,
@@ -328,6 +329,9 @@ internal class DrawerViewModelTest {
         val displayFolders = displayFoldersMap[displayAccounts[0].id] ?: emptyList()
         testSubject.event(Event.OnFolderClick(displayFolders[1]))
 
+        // Consume the state update
+        turbines.awaitStateItem()
+
         assertThat(turbines.awaitEffectItem()).isEqualTo(
             Effect.OpenFolder(
                 accountId = displayFolders[1].accountId,
@@ -355,6 +359,7 @@ internal class DrawerViewModelTest {
                 selectedAccountId = displayAccounts[0].id,
                 folders = displayFoldersMap[displayAccounts[0].id]!!.toImmutableList(),
                 selectedFolderId = displayFoldersMap[displayAccounts[0].id]!![0].id,
+                selectedFolder = displayFoldersMap[displayAccounts[0].id]!![0],
             )
             val testSubject = createTestSubject(
                 displayAccountsFlow = getDisplayAccountsFlow,
@@ -367,6 +372,9 @@ internal class DrawerViewModelTest {
             val displayFolders = displayFoldersMap[displayAccounts[0].id] ?: emptyList()
             testSubject.event(Event.OnFolderClick(displayFolders[1]))
 
+            // Consume the state update
+            turbines.awaitStateItem()
+
             assertThat(turbines.awaitEffectItem()).isEqualTo(Effect.OpenUnifiedFolder)
 
             turbines.assertThatAndEffectTurbineConsumed {
@@ -387,7 +395,7 @@ internal class DrawerViewModelTest {
             ).thenReturn(flowOf(Unit))
 
             val testSubject = createTestSubject(
-                initialState = State(config = drawerConfigWithAccountSelectorDisabled),
+                initialState = State(config = drawerConfigWithAccountSelectorDisabled, showAccountSelection = false),
                 saveDrawerConfig = saveDrawerConfig,
                 drawerConfigFlow = flowOf(drawerConfigWithAccountSelectorDisabled),
             )
@@ -398,6 +406,9 @@ internal class DrawerViewModelTest {
             advanceUntilIdle()
             verify(saveDrawerConfig, times(1)).invoke(captor.capture())
             assertThat(captor.firstValue).isEqualTo(drawerConfigWithAccountSelectorEnabled)
+
+            // Verify that showAccountSelection is toggled after the delay
+            assertThat(testSubject.state.value.showAccountSelection).isEqualTo(true)
         }
 
     @Suppress("MaxLineLength")
@@ -413,7 +424,7 @@ internal class DrawerViewModelTest {
             ).thenReturn(flowOf(Unit))
 
             val testSubject = createTestSubject(
-                initialState = State(config = drawerConfigWithAccountSelectorEnabled),
+                initialState = State(config = drawerConfigWithAccountSelectorEnabled, showAccountSelection = false),
                 saveDrawerConfig = saveDrawerConfig,
                 drawerConfigFlow = flowOf(drawerConfigWithAccountSelectorEnabled),
             )
@@ -424,6 +435,9 @@ internal class DrawerViewModelTest {
             advanceUntilIdle()
             verify(saveDrawerConfig, times(1)).invoke(captor.capture())
             assertThat(captor.firstValue).isEqualTo(drawerConfigWithAccountSelectorDisabled)
+
+            // Verify that showAccountSelection is toggled after the delay
+            assertThat(testSubject.state.value.showAccountSelection).isEqualTo(true)
         }
 
     @Test
@@ -453,7 +467,7 @@ internal class DrawerViewModelTest {
     private fun createTestSubject(
         initialState: State = State(),
         drawerConfigFlow: Flow<DrawerConfig> = flow { emit(createDrawerConfig()) },
-        displayAccountsFlow: Flow<List<DisplayAccount>> = flow { emit(emptyList()) },
+        displayAccountsFlow: Flow<List<MailDisplayAccount>> = flow { emit(emptyList()) },
         displayFoldersFlow: Flow<Map<String, List<DisplayFolder>>> = flow { emit(emptyMap()) },
         displayTreeFolder: DisplayTreeFolder = DisplayTreeFolder(
             displayFolder = null,
@@ -470,7 +484,7 @@ internal class DrawerViewModelTest {
             initialState = initialState,
             getDrawerConfig = { drawerConfigFlow },
             getDisplayAccounts = { displayAccountsFlow },
-            getDisplayFoldersForAccount = { accountId, _ ->
+            getDisplayFoldersForAccount = { accountId ->
                 displayFoldersFlow.map { it[accountId] ?: emptyList() }
             },
             getDisplayTreeFolder = { folders, maxDepth ->
@@ -500,8 +514,8 @@ internal class DrawerViewModelTest {
         email: String = "test@example.com",
         unreadCount: Int = 0,
         starredCount: Int = 0,
-    ): DisplayAccount {
-        return DisplayAccount(
+    ): MailDisplayAccount {
+        return MailDisplayAccount(
             id = id,
             name = name,
             email = email,
@@ -511,7 +525,7 @@ internal class DrawerViewModelTest {
         )
     }
 
-    private fun createDisplayAccountList(count: Int): List<DisplayAccount> {
+    private fun createDisplayAccountList(count: Int): List<MailDisplayAccount> {
         return List(count) { index ->
             createDisplayAccount(
                 id = "uuid-$index",
@@ -526,7 +540,7 @@ internal class DrawerViewModelTest {
         type: FolderType = FolderType.REGULAR,
         unreadCount: Int = 0,
         starredCount: Int = 0,
-    ): DisplayAccountFolder {
+    ): MailDisplayFolder {
         val folder = Folder(
             id = id,
             name = name,
@@ -534,7 +548,7 @@ internal class DrawerViewModelTest {
             isLocalOnly = false,
         )
 
-        return DisplayAccountFolder(
+        return MailDisplayFolder(
             accountId = accountId,
             folder = folder,
             isInTopGroup = false,
@@ -543,7 +557,7 @@ internal class DrawerViewModelTest {
         )
     }
 
-    private fun createDisplayFolderList(count: Int): List<DisplayAccountFolder> {
+    private fun createDisplayFolderList(count: Int): List<MailDisplayFolder> {
         return List(count) { index ->
             createDisplayFolder(
                 id = index.toLong() + 100,
@@ -553,11 +567,11 @@ internal class DrawerViewModelTest {
 
     private fun createDisplayUnifiedFolder(
         id: String = "unified_inbox",
-        unifiedType: DisplayUnifiedFolderType = DisplayUnifiedFolderType.INBOX,
+        unifiedType: UnifiedDisplayFolderType = UnifiedDisplayFolderType.INBOX,
         unreadCount: Int = 0,
         starredCount: Int = 0,
-    ): DisplayUnifiedFolder {
-        return DisplayUnifiedFolder(
+    ): UnifiedDisplayFolder {
+        return UnifiedDisplayFolder(
             id = id,
             unifiedType = unifiedType,
             unreadMessageCount = unreadCount,
