@@ -1,10 +1,10 @@
 package net.thunderbird.feature.widget.message.list
 
-import app.k9mail.legacy.account.SortType
-import net.thunderbird.feature.search.LocalSearch
+import net.thunderbird.core.android.account.SortType
+import net.thunderbird.feature.search.LocalMessageSearch
 
 internal data class MessageListConfig(
-    val search: LocalSearch,
+    val search: LocalMessageSearch,
     val showingThreadedList: Boolean,
     val sortType: SortType,
     val sortAscending: Boolean,
