@@ -5,7 +5,7 @@ plugins {
 dependencies {
     implementation(projects.legacy.ui.legacy)
     implementation(projects.legacy.core)
-    implementation(projects.legacy.account)
+    implementation(projects.core.android.account)
 }
 
 android {
