@@ -1,9 +1,9 @@
 package com.fsck.k9.controller.push
 
-import app.k9mail.legacy.account.LegacyAccount
 import app.k9mail.legacy.mailstore.FolderRepository
 import com.fsck.k9.backend.BackendManager
 import com.fsck.k9.controller.MessagingController
+import net.thunderbird.core.android.account.LegacyAccount
 
 internal class AccountPushControllerFactory(
     private val backendManager: BackendManager,
