@@ -7,7 +7,7 @@ import org.koin.dsl.module
 
 val helperModule = module {
     single { ClipboardManager(get()) }
-    single { MessageHelper(resourceProvider = get(), contactRepository = get()) }
+    single { MessageHelper(resourceProvider = get(), contactRepository = get(), generalSettingsManager = get()) }
     factory<KeyStoreDirectoryProvider> { AndroidKeyStoreDirectoryProvider(context = get()) }
     factory { get<Context>().getSystemService(Context.ALARM_SERVICE) as AlarmManager }
     factory<ContactNameProvider> { RealContactNameProvider(contactRepository = get()) }
