@@ -4,11 +4,8 @@ package com.fsck.k9.mailstore;
 import android.content.ContentValues;
 import android.database.Cursor;
 import android.database.sqlite.SQLiteDatabase;
-
 import androidx.annotation.NonNull;
-
 import androidx.annotation.Nullable;
-import app.k9mail.legacy.account.LegacyAccount;
 import app.k9mail.legacy.mailstore.MoreMessages;
 import com.fsck.k9.K9;
 import app.k9mail.legacy.message.controller.MessageReference;
@@ -35,6 +32,7 @@ import com.fsck.k9.mail.message.MessageHeaderParser;
 import com.fsck.k9.mailstore.LockableDatabase.DbCallback;
 import com.fsck.k9.message.extractors.AttachmentInfoExtractor;
 
+import net.thunderbird.core.android.account.LegacyAccount;
 import org.apache.commons.io.IOUtils;
 import org.apache.james.mime4j.util.MimeUtil;
 
@@ -54,7 +52,7 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 
-import timber.log.Timber;
+import net.thunderbird.core.logging.legacy.Log;
 
 
 public class LocalFolder {
@@ -796,7 +794,7 @@ public class LocalFolder {
                 try {
                     updateOrInsertMessagePart(db, new ContentValues(), part, messagePartId);
                 } catch (Exception e) {
-                    Timber.e(e, "Error writing message part");
+                    Log.e(e, "Error writing message part");
                 }
 
                 return null;
@@ -840,7 +838,7 @@ public class LocalFolder {
                     try {
                         message.setFlags(flags, value);
                     } catch (MessagingException e) {
-                        Timber.e(e, "Something went wrong while setting flag");
+                        Log.e(e, "Something went wrong while setting flag");
                     }
                 }
 
@@ -1110,7 +1108,7 @@ public class LocalFolder {
                 File file = localStore.getAttachmentFile(messagePartId);
                 if (file.exists()) {
                     if (!file.delete() && K9.isDebugLoggingEnabled()) {
-                        Timber.d("Couldn't delete message part file: %s", file.getAbsolutePath());
+                        Log.d("Couldn't delete message part file: %s", file.getAbsolutePath());
                     }
                 }
             }
