@@ -1,7 +1,7 @@
 package com.fsck.k9.notification
 
-import app.k9mail.legacy.account.LegacyAccount
 import app.k9mail.legacy.message.controller.MessageReference
+import net.thunderbird.core.android.account.LegacyAccount
 
 /**
  * Holds information about active and inactive new message notifications of an account.
