@@ -2,8 +2,8 @@ package com.fsck.k9.notification
 
 import android.os.Build
 import androidx.annotation.RequiresApi
-import app.k9mail.legacy.account.LegacyAccount
 import com.fsck.k9.Preferences
+import net.thunderbird.core.android.account.LegacyAccount
 
 /**
  * Update accounts with notification settings read from their "Messages" `NotificationChannel`.
