@@ -1,8 +1,8 @@
 package com.fsck.k9.notification
 
-import app.k9mail.legacy.account.LegacyAccount
 import com.fsck.k9.mailstore.LocalFolder
 import com.fsck.k9.mailstore.LocalMessage
+import net.thunderbird.core.android.account.LegacyAccount
 
 interface NotificationStrategy {
 
