@@ -1,18 +1,18 @@
 package com.fsck.k9.preferences
 
-import app.k9mail.legacy.account.AccountManager
-import com.fsck.k9.K9
+import net.thunderbird.core.android.account.AccountManager
+import net.thunderbird.core.preference.GeneralSettingsManager
 
 /**
  * Configures the unified inbox after an account has been added.
  */
 class UnifiedInboxConfigurator(
     private val accountManager: AccountManager,
+    private val generalSettingsManager: GeneralSettingsManager,
 ) {
     fun configureUnifiedInbox() {
         if (accountManager.getAccounts().size == 2) {
-            K9.isShowUnifiedInbox = true
-            K9.saveSettingsAsync()
+            generalSettingsManager.setIsShowUnifiedInbox(isShowUnifiedInbox = true)
         }
     }
 }
