@@ -12,10 +12,12 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import androidx.annotation.NonNull;
+import kotlinx.coroutines.flow.Flow;
 import net.thunderbird.core.android.testing.RobolectricTest;
-import app.k9mail.legacy.account.QuoteStyle;
+import net.thunderbird.core.android.account.QuoteStyle;
 import com.fsck.k9.CoreResourceProvider;
-import app.k9mail.legacy.account.Identity;
+import net.thunderbird.core.android.account.Identity;
 import com.fsck.k9.TestCoreResourceProvider;
 import com.fsck.k9.mail.Address;
 import com.fsck.k9.mail.BodyPart;
@@ -29,6 +31,14 @@ import com.fsck.k9.mail.internet.MimeMessage;
 import com.fsck.k9.mail.internet.MimeMultipart;
 import com.fsck.k9.message.MessageBuilder.Callback;
 import com.fsck.k9.message.quote.InsertableHtmlContent;
+import net.thunderbird.core.logging.legacy.Log;
+import net.thunderbird.core.logging.testing.TestLogger;
+import net.thunderbird.core.preference.AppTheme;
+import net.thunderbird.core.preference.BackgroundSync;
+import net.thunderbird.core.preference.GeneralSettings;
+import net.thunderbird.core.preference.GeneralSettingsManager;
+import net.thunderbird.core.preference.SubTheme;
+import net.thunderbird.core.preference.privacy.PrivacySettings;
 import org.junit.Before;
 import org.junit.Test;
 import org.mockito.ArgumentCaptor;
@@ -195,10 +205,188 @@ public class MessageBuilderTest extends RobolectricTest {
     private BoundaryGenerator boundaryGenerator;
     private CoreResourceProvider resourceProvider = new TestCoreResourceProvider();
     private Callback callback;
+    private final GeneralSettingsManager fakeSettingsManager = new GeneralSettingsManager() {
+        @Override
+        public void setIsHideTimeZone(boolean isHideTimeZone) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @NonNull
+        @Override
+        public PrivacySettings getPrivacySettings() {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsQuietTimeEnabled(boolean isQuietTimeEnabled) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setQuietTimeStarts(@NonNull String quietTimeStarts) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setQuietTimeEnds(@NonNull String quietTimeEnds) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @NonNull
+        @Override
+        public GeneralSettings getSettings() {
+            return new GeneralSettings(
+                BackgroundSync.NEVER,
+                false,
+                AppTheme.FOLLOW_SYSTEM,
+                SubTheme.USE_GLOBAL,
+                SubTheme.USE_GLOBAL,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                false,
+                "07:00",
+                "07:00",
+                false,
+                false,
+                new PrivacySettings(false, false)
+            );
+        }
+
+        @NonNull
+        @Override
+        public Flow<GeneralSettings> getSettingsFlow() {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setShowRecentChanges(boolean showRecentChanges) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setAppTheme(@NonNull AppTheme appTheme) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setMessageViewTheme(@NonNull SubTheme subTheme) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setMessageComposeTheme(@NonNull SubTheme subTheme) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setFixedMessageViewTheme(boolean fixedMessageViewTheme) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsShowUnifiedInbox(boolean isShowUnifiedInbox) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsShowStarredCount(boolean isShowStarredCount) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsShowMessageListStars(boolean isShowMessageListStars) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsShowAnimations(boolean isShowAnimations) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsShowCorrespondentNames(boolean isShowCorrespondentNames) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setSetupArchiveShouldNotShowAgain(boolean shouldShowSetupArchiveFolderDialog) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsMessageListSenderAboveSubject(boolean isMessageListSenderAboveSubject) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsShowContactName(boolean isShowContactName) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsShowContactPicture(boolean isShowContactPicture) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsChangeContactNameColor(boolean isChangeContactNameColor) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsColorizeMissingContactPictures(boolean isColorizeMissingContactPictures) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsUseBackgroundAsUnreadIndicator(boolean isUseBackgroundAsUnreadIndicator) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsShowComposeButtonOnMessageList(boolean isShowComposeButtonOnMessageList) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsThreadedViewEnabled(boolean isThreadedViewEnabled) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsUseMessageViewFixedWidthFont(boolean isUseMessageViewFixedWidthFont) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsAutoFitWidth(boolean isAutoFitWidth) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+
+        @Override
+        public void setIsHideUserAgent(boolean isHideUserAgent) {
+            throw new UnsupportedOperationException("not implemented");
+        }
+    };
 
 
     @Before
     public void setUp() throws Exception {
+        Log.logger = new TestLogger();
         messageIdGenerator = mock(MessageIdGenerator.class);
         when(messageIdGenerator.generateMessageId(any(Message.class))).thenReturn(TEST_MESSAGE_ID);
 
@@ -342,7 +530,7 @@ public class MessageBuilderTest extends RobolectricTest {
 
     @Test
     public void buildWithException_shouldThrow() throws MessagingException {
-        MessageBuilder messageBuilder = new SimpleMessageBuilder(messageIdGenerator, boundaryGenerator, resourceProvider) {
+        MessageBuilder messageBuilder = new SimpleMessageBuilder(messageIdGenerator, boundaryGenerator, resourceProvider, fakeSettingsManager) {
             @Override
             protected void buildMessageInternal() {
                 queueMessageBuildException(new MessagingException("expected error"));
@@ -358,7 +546,7 @@ public class MessageBuilderTest extends RobolectricTest {
     @Test
     public void buildWithException_detachAndReattach_shouldThrow() throws MessagingException {
         Callback anotherCallback = mock(Callback.class);
-        MessageBuilder messageBuilder = new SimpleMessageBuilder(messageIdGenerator, boundaryGenerator, resourceProvider) {
+        MessageBuilder messageBuilder = new SimpleMessageBuilder(messageIdGenerator, boundaryGenerator, resourceProvider, fakeSettingsManager) {
             @Override
             protected void buildMessageInternal() {
                 queueMessageBuildException(new MessagingException("expected error"));
@@ -433,7 +621,7 @@ public class MessageBuilderTest extends RobolectricTest {
 
     private MessageBuilder createSimpleMessageBuilder() {
         Identity identity = createIdentity();
-        return new SimpleMessageBuilder(messageIdGenerator, boundaryGenerator, resourceProvider)
+        return new SimpleMessageBuilder(messageIdGenerator, boundaryGenerator, resourceProvider, fakeSettingsManager)
                 .setSubject(TEST_SUBJECT)
                 .setSentDate(SENT_DATE)
                 .setHideTimeZone(true)
