@@ -1,9 +1,9 @@
 package net.thunderbird.legacy.core
 
-import app.k9mail.legacy.account.AccountDefaultsProvider
-import app.k9mail.legacy.account.Identity
-import app.k9mail.legacy.account.LegacyAccount
-import net.thunderbird.core.preferences.Storage
+import net.thunderbird.core.android.account.AccountDefaultsProvider
+import net.thunderbird.core.android.account.Identity
+import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.preference.storage.Storage
 
 class FakeAccountDefaultsProvider : AccountDefaultsProvider {
     override fun applyDefaults(account: LegacyAccount) {
