@@ -1,15 +1,15 @@
 package app.k9mail.legacy.message.controller
 
-import app.k9mail.legacy.account.LegacyAccount
 import kotlinx.coroutines.flow.Flow
-import net.thunderbird.feature.search.LocalSearch
+import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.feature.search.LocalMessageSearch
 import net.thunderbird.feature.search.SearchAccount
 
 interface MessageCountsProvider {
     fun getMessageCounts(account: LegacyAccount): MessageCounts
     fun getMessageCounts(searchAccount: SearchAccount): MessageCounts
-    fun getMessageCounts(search: LocalSearch): MessageCounts
-    fun getMessageCountsFlow(search: LocalSearch): Flow<MessageCounts>
+    fun getMessageCounts(search: LocalMessageSearch): MessageCounts
+    fun getMessageCountsFlow(search: LocalMessageSearch): Flow<MessageCounts>
     fun getUnreadMessageCount(account: LegacyAccount, folderId: Long): Int
 }
 
