@@ -4,7 +4,7 @@ import com.fsck.k9.K9
 import com.fsck.k9.helper.FileHelper
 import com.fsck.k9.mailstore.StorageFilesProvider
 import java.io.File
-import timber.log.Timber
+import net.thunderbird.core.logging.legacy.Log
 
 internal class AttachmentFileManager(
     private val storageFilesProvider: StorageFilesProvider,
@@ -12,7 +12,7 @@ internal class AttachmentFileManager(
     fun deleteFile(messagePartId: Long) {
         val file = getAttachmentFile(messagePartId)
         if (file.exists() && !file.delete() && K9.isDebugLoggingEnabled) {
-            Timber.w("Couldn't delete message part file: %s", file.absolutePath)
+            Log.w("Couldn't delete message part file: %s", file.absolutePath)
         }
     }
 
