@@ -1,6 +1,6 @@
 package com.fsck.k9.ui.managefolders
 
-import org.koin.androidx.viewmodel.dsl.viewModel
+import org.koin.core.module.dsl.viewModel
 import org.koin.dsl.module
 
 val manageFoldersUiModule = module {
