@@ -18,30 +18,25 @@ import androidx.appcompat.view.ActionMode
 import androidx.core.os.BundleCompat
 import androidx.core.os.bundleOf
 import androidx.core.view.ViewCompat
-import androidx.core.view.WindowInsetsCompat
 import androidx.core.view.WindowInsetsCompat.Type.navigationBars
 import androidx.core.view.WindowInsetsCompat.Type.systemBars
-import androidx.core.view.insets.GradientProtection
-import androidx.core.view.insets.ProtectionLayout
 import androidx.core.view.isGone
 import androidx.core.view.isVisible
 import androidx.core.view.setPadding
 import androidx.core.view.updateLayoutParams
 import androidx.fragment.app.Fragment
+import androidx.fragment.app.setFragmentResultListener
 import androidx.lifecycle.Observer
+import androidx.lifecycle.lifecycleScope
 import androidx.recyclerview.widget.RecyclerView
 import androidx.swiperefreshlayout.widget.SwipeRefreshLayout
-import app.k9mail.legacy.account.AccountManager
-import app.k9mail.legacy.account.Expunge
-import app.k9mail.legacy.account.LegacyAccount
-import app.k9mail.legacy.account.SortType
 import app.k9mail.legacy.message.controller.MessageReference
 import app.k9mail.legacy.message.controller.SimpleMessagingListener
 import app.k9mail.legacy.ui.folder.FolderNameFormatter
 import app.k9mail.ui.utils.itemtouchhelper.ItemTouchHelper
 import app.k9mail.ui.utils.linearlayoutmanager.LinearLayoutManager
 import com.fsck.k9.K9
-import com.fsck.k9.SwipeAction
+import com.fsck.k9.Preferences
 import com.fsck.k9.activity.FolderInfoHolder
 import com.fsck.k9.activity.Search
 import com.fsck.k9.activity.misc.ContactPicture
@@ -65,15 +60,31 @@ import com.google.android.material.snackbar.BaseTransientBottomBar.BaseCallback
 import com.google.android.material.snackbar.Snackbar
 import com.google.android.material.textview.MaterialTextView
 import java.util.concurrent.Future
+import kotlinx.coroutines.flow.distinctUntilChanged
+import kotlinx.coroutines.flow.drop
+import kotlinx.coroutines.flow.launchIn
+import kotlinx.coroutines.flow.map
+import kotlinx.coroutines.flow.onEach
 import kotlinx.datetime.Clock
 import net.jcip.annotations.GuardedBy
+import net.thunderbird.core.android.account.AccountManager
+import net.thunderbird.core.android.account.Expunge
+import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountWrapper
+import net.thunderbird.core.android.account.SortType
 import net.thunderbird.core.android.network.ConnectivityManager
-import net.thunderbird.feature.search.LocalSearch
+import net.thunderbird.core.architecture.data.DataMapper
+import net.thunderbird.core.common.action.SwipeAction
+import net.thunderbird.core.logging.legacy.Log
+import net.thunderbird.core.preference.GeneralSettingsManager
+import net.thunderbird.feature.account.storage.legacy.mapper.DefaultLegacyAccountWrapperDataMapper
+import net.thunderbird.feature.mail.message.list.domain.DomainContract
+import net.thunderbird.feature.mail.message.list.ui.dialog.SetupArchiveFolderDialogFragmentFactory
+import net.thunderbird.feature.search.LocalMessageSearch
 import net.thunderbird.feature.search.SearchAccount
 import org.koin.android.ext.android.inject
 import org.koin.androidx.viewmodel.ext.android.viewModel
 import org.koin.core.parameter.parametersOf
-import timber.log.Timber
 
 private const val MAXIMUM_MESSAGE_SORT_OVERRIDES = 3
 private const val MINIMUM_CLICK_INTERVAL = 200L
@@ -87,12 +98,22 @@ class MessageListFragment :
     val viewModel: MessageListViewModel by viewModel()
     private val recentChangesViewModel: RecentChangesViewModel by viewModel()
 
+    private val generalSettingsManager: GeneralSettingsManager by inject()
     private val sortTypeToastProvider: SortTypeToastProvider by inject()
     private val folderNameFormatter: FolderNameFormatter by inject { parametersOf(requireContext()) }
     private val messagingController: MessagingController by inject()
     private val accountManager: AccountManager by inject()
     private val connectivityManager: ConnectivityManager by inject()
     private val clock: Clock by inject()
+    private val setupArchiveFolderDialogFragmentFactory: SetupArchiveFolderDialogFragmentFactory by inject()
+    private val legacyAccountWrapperDataMapper: DataMapper<
+        LegacyAccountWrapper,
+        LegacyAccount,
+        > by inject<DefaultLegacyAccountWrapperDataMapper>()
+    private val preferences: Preferences by inject()
+    private val buildSwipeActions: DomainContract.UseCase.BuildSwipeActions<LegacyAccount> by inject {
+        parametersOf(preferences.storage)
+    }
 
     private val handler = MessageListHandler(this)
     private val activityListener = MessageListActivityListener()
@@ -122,6 +143,7 @@ class MessageListFragment :
     private lateinit var adapter: MessageListAdapter
 
     private lateinit var accountUuids: Array<String>
+    private var accounts: List<LegacyAccountWrapper> = emptyList()
     private var account: LegacyAccount? = null
     private var currentFolder: FolderInfoHolder? = null
     private var remoteSearchFuture: Future<*>? = null
@@ -146,7 +168,7 @@ class MessageListFragment :
     private var rememberedSelected: Set<Long>? = null
     private var lastMessageClick = 0L
 
-    lateinit var localSearch: LocalSearch
+    lateinit var localSearch: LocalMessageSearch
         private set
     var isSingleAccountMode = false
         private set
@@ -168,6 +190,8 @@ class MessageListFragment :
 
     private var error: Error? = null
 
+    private var messageListSwipeCallback: MessageListSwipeCallback? = null
+
     /**
      * Set this to `true` when the fragment should be considered active. When active, the fragment adds its actions to
      * the toolbar. When inactive, the fragment won't add its actions to the toolbar, even it is still visible, e.g. as
@@ -211,6 +235,21 @@ class MessageListFragment :
 
         adapter = createMessageListAdapter()
 
+        generalSettingsManager.getSettingsFlow()
+            /**
+             * Skips the first emitted item from the settings flow,
+             * since the initial value of `showingThreadedList` is taken
+             * from the fragment's arguments rather than the flow.
+             */
+            .drop(1)
+            .map { it.isThreadedViewEnabled }
+            .distinctUntilChanged()
+            .onEach {
+                showingThreadedList = it
+                loadMessageList(forceUpdate = true)
+            }
+            .launchIn(lifecycleScope)
+
         isInitialized = true
     }
 
@@ -232,10 +271,10 @@ class MessageListFragment :
         val arguments = requireArguments()
         showingThreadedList = arguments.getBoolean(ARG_THREADED_LIST, false)
         isThreadDisplay = arguments.getBoolean(ARG_IS_THREAD_DISPLAY, false)
-        localSearch = BundleCompat.getParcelable(arguments, ARG_SEARCH, LocalSearch::class.java)!!
+        localSearch = BundleCompat.getParcelable(arguments, ARG_SEARCH, LocalMessageSearch::class.java)!!
 
         allAccounts = localSearch.searchAllAccounts()
-        val searchAccounts = localSearch.getAccounts(accountManager)
+        val searchAccounts = localSearch.getAccounts(accountManager).also(::updateAccountList)
         if (searchAccounts.size == 1) {
             isSingleAccountMode = true
             val singleAccount = searchAccounts[0]
@@ -284,15 +323,17 @@ class MessageListFragment :
                     typedValued,
                     true,
                 )
-                view.findViewById<ProtectionLayout>(R.id.protection_layout)
-                    .setProtections(
-                        listOf(
-                            GradientProtection(
-                                WindowInsetsCompat.Side.BOTTOM,
-                                typedValued.data,
-                            ),
-                        ),
+
+                setFragmentResultListener(
+                    SetupArchiveFolderDialogFragmentFactory.RESULT_CODE_DISMISS_REQUEST_KEY,
+                ) { key, bundle ->
+                    Log.d(
+                        "SetupArchiveFolderDialogFragment fragment listener triggered with " +
+                            "key: $key and bundle: $bundle",
                     )
+                    loadMessageList(forceUpdate = true)
+                    messageListSwipeCallback?.invalidateSwipeActions(accounts)
+                }
             }
         } else {
             inflater.inflate(R.layout.message_list_error, container, false)
@@ -353,7 +394,7 @@ class MessageListFragment :
     }
 
     private fun initializeFloatingActionButton(view: View) {
-        isShowFloatingActionButton = K9.isShowComposeButtonOnMessageList
+        isShowFloatingActionButton = generalSettingsManager.getSettings().isShowComposeButtonOnMessageList
         if (isShowFloatingActionButton) {
             enableFloatingActionButton(view)
         } else {
@@ -372,7 +413,7 @@ class MessageListFragment :
             v.updateLayoutParams<ViewGroup.MarginLayoutParams> {
                 val fabMargin = view.resources.getDimensionPixelSize(R.dimen.floatingActionButtonMargin)
 
-                bottomMargin = fabMargin + insets.bottom
+                bottomMargin = fabMargin
                 rightMargin = fabMargin + insets.right
                 leftMargin = fabMargin + insets.left
             }
@@ -408,14 +449,15 @@ class MessageListFragment :
 
         val itemTouchHelper = ItemTouchHelper(
             MessageListSwipeCallback(
-                requireContext(),
+                context = requireContext(),
                 resourceProvider = SwipeResourceProvider(requireContext()),
-                swipeActionSupportProvider,
-                swipeRightAction = K9.swipeRightAction,
-                swipeLeftAction = K9.swipeLeftAction,
-                adapter,
-                swipeListener,
-            ),
+                swipeActionSupportProvider = swipeActionSupportProvider,
+                buildSwipeActions = buildSwipeActions,
+                adapter = adapter,
+                listener = swipeListener,
+                accounts = accounts,
+                legacyAccountWrapperDataMapper = legacyAccountWrapperDataMapper,
+            ).also { messageListSwipeCallback = it },
         )
         itemTouchHelper.attachToRecyclerView(recyclerView)
 
@@ -474,7 +516,7 @@ class MessageListFragment :
         }
     }
 
-    private fun loadMessageList() {
+    private fun loadMessageList(forceUpdate: Boolean = false) {
         val config = MessageListConfig(
             localSearch,
             showingThreadedList,
@@ -484,7 +526,16 @@ class MessageListFragment :
             activeMessage,
             viewModel.messageSortOverrides.toMap(),
         )
-        viewModel.loadMessageList(config)
+
+        if (forceUpdate) {
+            updateAccountList(accounts = config.search.getAccounts(accountManager))
+        }
+
+        viewModel.loadMessageList(config, forceUpdate)
+    }
+
+    private fun updateAccountList(accounts: List<LegacyAccount>) {
+        this.accounts = accounts.map(legacyAccountWrapperDataMapper::toDomain)
     }
 
     fun folderLoading(folderId: Long, loading: Boolean) {
@@ -607,6 +658,7 @@ class MessageListFragment :
 
     override fun onDestroyView() {
         recyclerView = null
+        messageListSwipeCallback = null
         itemTouchHelper = null
         swipeRefreshLayout = null
         floatingActionButton = null
@@ -638,11 +690,11 @@ class MessageListFragment :
         get() = MessageListAppearance(
             fontSizes = K9.fontSizes,
             previewLines = K9.messageListPreviewLines,
-            stars = !isOutbox && K9.isShowMessageListStars,
-            senderAboveSubject = K9.isMessageListSenderAboveSubject,
-            showContactPicture = K9.isShowContactPicture,
+            stars = !isOutbox && generalSettingsManager.getSettings().isShowMessageListStars,
+            senderAboveSubject = generalSettingsManager.getSettings().isMessageListSenderAboveSubject,
+            showContactPicture = generalSettingsManager.getSettings().isShowContactPicture,
             showingThreadedList = showingThreadedList,
-            backGroundAsReadIndicator = K9.isUseBackgroundAsUnreadIndicator,
+            backGroundAsReadIndicator = generalSettingsManager.getSettings().isUseBackgroundAsUnreadIndicator,
             showAccountChip = isShowAccountChip,
             density = K9.messageListDensity,
         )
@@ -1229,15 +1281,19 @@ class MessageListFragment :
         if (messages.isEmpty()) return false
 
         val account = accountManager.getAccount(messages.first().accountUuid)
-        if (operation == FolderOperation.MOVE && !messagingController.isMoveCapable(account) ||
-            operation == FolderOperation.COPY && !messagingController.isCopyCapable(account)
+        if (operation == FolderOperation.MOVE &&
+            !messagingController.isMoveCapable(account) ||
+            operation == FolderOperation.COPY &&
+            !messagingController.isCopyCapable(account)
         ) {
             return false
         }
 
         for (message in messages) {
-            if (operation == FolderOperation.MOVE && !messagingController.isMoveCapable(message) ||
-                operation == FolderOperation.COPY && !messagingController.isCopyCapable(message)
+            if (operation == FolderOperation.MOVE &&
+                !messagingController.isMoveCapable(message) ||
+                operation == FolderOperation.COPY &&
+                !messagingController.isCopyCapable(message)
             ) {
                 val toast = Toast.makeText(
                     activity,
@@ -1365,12 +1421,12 @@ class MessageListFragment :
         // If we represent a remote search, then kill that before going back.
         if (isRemoteSearch && remoteSearchFuture != null) {
             try {
-                Timber.i("Remote search in progress, attempting to abort...")
+                Log.i("Remote search in progress, attempting to abort...")
 
                 // Canceling the future stops any message fetches in progress.
                 val cancelSuccess = remoteSearchFuture!!.cancel(true) // mayInterruptIfRunning = true
                 if (!cancelSuccess) {
-                    Timber.e("Could not cancel remote search future.")
+                    Log.e("Could not cancel remote search future.")
                 }
 
                 // Closing the folder will kill off the connection if we're mid-search.
@@ -1385,7 +1441,7 @@ class MessageListFragment :
                 )
             } catch (e: Exception) {
                 // Since the user is going back, log and squash any exceptions.
-                Timber.e(e, "Could not abort remote search before going back")
+                Log.e(e, "Could not abort remote search before going back")
             }
         }
 
@@ -1731,6 +1787,20 @@ class MessageListFragment :
                     setFlag(item, Flag.FLAGGED, !item.isStarred)
                 }
 
+                SwipeAction.ArchiveDisabled ->
+                    Snackbar
+                        .make(
+                            requireNotNull(view),
+                            R.string.archiving_not_available_for_this_account,
+                            Snackbar.LENGTH_LONG,
+                        )
+                        .show()
+
+                SwipeAction.ArchiveSetupArchiveFolder -> setupArchiveFolderDialogFragmentFactory.show(
+                    accountUuid = item.account.uuid,
+                    fragmentManager = parentFragmentManager,
+                )
+
                 SwipeAction.Archive -> {
                     onArchive(item.messageReference)
                 }
@@ -1769,8 +1839,8 @@ class MessageListFragment :
             SwipeAction.ToggleSelection -> true
             SwipeAction.ToggleRead -> !isOutbox
             SwipeAction.ToggleStar -> !isOutbox
-            SwipeAction.Archive -> {
-                !isOutbox && item.account.hasArchiveFolder() && item.folderId != item.account.archiveFolderId
+            SwipeAction.Archive, SwipeAction.ArchiveDisabled, SwipeAction.ArchiveSetupArchiveFolder -> {
+                !isOutbox && item.folderId != item.account.archiveFolderId
             }
 
             SwipeAction.Delete -> true
@@ -2168,7 +2238,11 @@ class MessageListFragment :
         private const val STATE_ACTIVE_MESSAGE = "activeMessage"
         private const val STATE_REMOTE_SEARCH_PERFORMED = "remoteSearchPerformed"
 
-        fun newInstance(search: LocalSearch, isThreadDisplay: Boolean, threadedList: Boolean): MessageListFragment {
+        fun newInstance(
+            search: LocalMessageSearch,
+            isThreadDisplay: Boolean,
+            threadedList: Boolean,
+        ): MessageListFragment {
             return MessageListFragment().apply {
                 arguments = bundleOf(
                     ARG_SEARCH to search,
