@@ -6,8 +6,12 @@ import androidx.lifecycle.ViewModel
 import androidx.lifecycle.viewModelScope
 import app.k9mail.legacy.message.controller.MessageReference
 import java.util.LinkedList
+import net.thunderbird.core.logging.Logger
 
-class MessageListViewModel(private val messageListLiveDataFactory: MessageListLiveDataFactory) : ViewModel() {
+class MessageListViewModel(
+    private val messageListLiveDataFactory: MessageListLiveDataFactory,
+    private val logger: Logger,
+) : ViewModel() {
     private var currentMessageListLiveData: MessageListLiveData? = null
     private val messageListLiveData = MediatorLiveData<MessageListInfo>()
 
@@ -17,8 +21,9 @@ class MessageListViewModel(private val messageListLiveDataFactory: MessageListLi
         return messageListLiveData
     }
 
-    fun loadMessageList(config: MessageListConfig) {
-        if (currentMessageListLiveData?.config == config) return
+    fun loadMessageList(config: MessageListConfig, forceUpdate: Boolean = false) {
+        logger.debug { "loadMessageList() called with: config = $config, forceUpdate = $forceUpdate" }
+        if (!forceUpdate && currentMessageListLiveData?.config == config) return
 
         removeCurrentMessageListLiveData()
 
@@ -26,6 +31,7 @@ class MessageListViewModel(private val messageListLiveDataFactory: MessageListLi
         currentMessageListLiveData = liveData
 
         messageListLiveData.addSource(liveData) { items ->
+            logger.debug { "Received new MessageListInfo: $items" }
             messageListLiveData.value = items
         }
     }
