@@ -1,12 +1,12 @@
 package com.fsck.k9.ui.settings.account
 
-import app.k9mail.legacy.account.LegacyAccount
 import com.fsck.k9.Preferences
 import com.fsck.k9.controller.MessagingController
 import com.fsck.k9.job.K9JobManager
 import com.fsck.k9.notification.NotificationChannelManager
 import com.fsck.k9.notification.NotificationController
 import java.util.concurrent.ExecutorService
+import net.thunderbird.core.android.account.LegacyAccount
 
 class AccountSettingsDataStoreFactory(
     private val preferences: Preferences,
