@@ -1,10 +1,14 @@
 package com.fsck.k9.view
 
-import app.k9mail.core.ui.theme.api.Theme
 import com.fsck.k9.K9
+import net.thunderbird.core.preference.GeneralSettingsManager
+import net.thunderbird.core.ui.theme.api.Theme
 import net.thunderbird.core.ui.theme.manager.ThemeManager
 
-class WebViewConfigProvider(private val themeManager: ThemeManager) {
+class WebViewConfigProvider(
+    private val themeManager: ThemeManager,
+    private val generalSettingsManager: GeneralSettingsManager,
+) {
     fun createForMessageView() = createWebViewConfig(themeManager.messageViewTheme)
 
     fun createForMessageCompose() = createWebViewConfig(themeManager.messageComposeTheme)
@@ -12,7 +16,7 @@ class WebViewConfigProvider(private val themeManager: ThemeManager) {
     private fun createWebViewConfig(theme: Theme): WebViewConfig {
         return WebViewConfig(
             useDarkMode = theme == Theme.DARK,
-            autoFitWidth = K9.isAutoFitWidth,
+            autoFitWidth = generalSettingsManager.getSettings().isAutoFitWidth,
             textZoom = K9.fontSizes.messageViewContentAsPercent,
         )
     }
