@@ -10,8 +10,6 @@ import android.widget.LinearLayout
 import androidx.appcompat.app.AppCompatActivity
 import androidx.core.view.isGone
 import androidx.core.view.isVisible
-import app.k9mail.core.testing.TestClock
-import app.k9mail.legacy.account.LegacyAccount
 import assertk.Assert
 import assertk.assertThat
 import assertk.assertions.isEqualTo
@@ -26,7 +24,9 @@ import com.fsck.k9.mail.Address
 import com.fsck.k9.ui.R
 import com.fsck.k9.ui.helper.RelativeDateTimeFormatter
 import com.google.android.material.textview.MaterialTextView
+import net.thunderbird.core.android.account.LegacyAccount
 import net.thunderbird.core.android.testing.RobolectricTest
+import net.thunderbird.core.testing.TestClock
 import org.junit.Test
 import org.mockito.kotlin.mock
 import org.robolectric.Robolectric
@@ -425,7 +425,9 @@ class MessageListAdapterTest : RobolectricTest() {
     }
 
     fun createMessageListItem(
-        account: LegacyAccount = LegacyAccount(SOME_ACCOUNT_UUID),
+        account: LegacyAccount = LegacyAccount(
+            SOME_ACCOUNT_UUID,
+        ),
         subject: String? = "irrelevant",
         threadCount: Int = 0,
         messageDate: Long = 0L,
