@@ -10,7 +10,7 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 
-import com.fsck.k9.logging.Timber;
+import net.thunderbird.core.logging.legacy.Log;
 import com.fsck.k9.mail.FetchProfile;
 import com.fsck.k9.mail.Flag;
 import com.fsck.k9.mail.K9MailLib;
@@ -173,7 +173,7 @@ public class Pop3Folder {
                     // response = "+OK msgNum msgUid"
                     String[] uidParts = response.split(" +");
                     if (uidParts.length < 3 || !"+OK".equals(uidParts[0])) {
-                        Timber.e("ERR response: %s", response);
+                        Log.e("ERR response: %s", response);
                         return;
                     }
                     String msgUid = uidParts[2];
@@ -233,7 +233,7 @@ public class Pop3Folder {
         for (String uid : uids) {
             if (uidToMsgMap.get(uid) == null) {
                 if (K9MailLib.isDebug() && DEBUG_PROTOCOL_POP3) {
-                    Timber.d("Need to index UID %s", uid);
+                    Log.d("Need to index UID %s", uid);
                 }
                 unindexedUids.add(uid);
             }
@@ -260,7 +260,7 @@ public class Pop3Folder {
                 String msgUid = uidParts[1];
                 if (unindexedUids.contains(msgUid)) {
                     if (K9MailLib.isDebug() && DEBUG_PROTOCOL_POP3) {
-                        Timber.d("Got msgNum %d for UID %s", msgNum, msgUid);
+                        Log.d("Got msgNum %d for UID %s", msgNum, msgUid);
                     }
 
                     Pop3Message message = uidToMsgMap.get(msgUid);
@@ -275,7 +275,7 @@ public class Pop3Folder {
 
     private void indexMessage(int msgNum, Pop3Message message) {
         if (K9MailLib.isDebug() && DEBUG_PROTOCOL_POP3) {
-            Timber.d("Adding index for UID %s to msgNum %d", message.getUid(), msgNum);
+            Log.d("Adding index for UID %s to msgNum %d", message.getUid(), msgNum);
         }
         msgNumToMsgMap.put(msgNum, message);
         uidToMsgMap.put(message.getUid(), message);
@@ -417,7 +417,7 @@ public class Pop3Folder {
         if (lines != -1 && (!connection.isTopNotAdvertised() || connection.supportsTop())) {
             try {
                 if (K9MailLib.isDebug() && DEBUG_PROTOCOL_POP3 && !connection.supportsTop()) {
-                    Timber.d("This server doesn't support the CAPA command. " +
+                    Log.d("This server doesn't support the CAPA command. " +
                           "Checking to see if the TOP command is supported nevertheless.");
                 }
 
@@ -432,7 +432,7 @@ public class Pop3Folder {
                     throw e;
                 } else {
                     if (K9MailLib.isDebug() && DEBUG_PROTOCOL_POP3) {
-                        Timber.d("The server really doesn't support the TOP " +
+                        Log.d("The server really doesn't support the TOP " +
                               "command. Using RETR instead.");
                     }
 
