@@ -1,6 +1,5 @@
 package com.fsck.k9.mail.transport.smtp
 
-import com.fsck.k9.logging.Timber
 import com.fsck.k9.mail.Address
 import com.fsck.k9.mail.AuthType
 import com.fsck.k9.mail.Authentication
@@ -37,6 +36,7 @@ import java.net.UnknownHostException
 import java.security.GeneralSecurityException
 import java.util.Locale
 import javax.net.ssl.SSLException
+import net.thunderbird.core.logging.legacy.Log
 import org.apache.commons.io.IOUtils
 import org.jetbrains.annotations.VisibleForTesting
 
@@ -67,6 +67,7 @@ class SmtpTransport(
     private var outputStream: OutputStream? = null
     private var responseParser: SmtpResponseParser? = null
     private var is8bitEncodingAllowed = false
+    private var areUnicodeAddressesAllowed = false
     private var isEnhancedStatusCodesProvided = false
     private var largestAcceptableMessage = 0
     private var retryOAuthWithNewToken = false
@@ -77,7 +78,7 @@ class SmtpTransport(
             get() = K9MailLib.isDebug()
 
         override fun log(throwable: Throwable?, message: String, vararg args: Any?) {
-            Timber.v(throwable, message, *args)
+            Log.v(throwable, message, *args)
         }
     }
 
@@ -106,6 +107,7 @@ class SmtpTransport(
             var extensions = sendHello(SMTP_HELLO_NAME)
 
             is8bitEncodingAllowed = extensions.containsKey("8BITMIME")
+            areUnicodeAddressesAllowed = extensions.containsKey("SMTPUTF8")
             isEnhancedStatusCodesProvided = extensions.containsKey("ENHANCEDSTATUSCODES")
             isPipeliningSupported = extensions.containsKey("PIPELINING")
 
@@ -220,7 +222,7 @@ class SmtpTransport(
             connectException = try {
                 return connectToAddress(address)
             } catch (e: IOException) {
-                Timber.w(e, "Could not connect to %s", address)
+                Log.w(e, "Could not connect to %s", address)
                 e
             }
         }
@@ -230,7 +232,7 @@ class SmtpTransport(
 
     private fun connectToAddress(address: InetAddress): Socket {
         if (K9MailLib.isDebug() && K9MailLib.DEBUG_PROTOCOL_SMTP) {
-            Timber.d("Connecting to %s as %s", host, address)
+            Log.d("Connecting to %s as %s", host, address)
         }
 
         val socketAddress = InetSocketAddress(address, port)
@@ -257,7 +259,7 @@ class SmtpTransport(
     private fun logResponse(smtpResponse: SmtpResponse, sensitive: Boolean = false) {
         if (K9MailLib.isDebug()) {
             val omitText = sensitive && !K9MailLib.isDebugSensitive()
-            Timber.v("%s", smtpResponse.toLogString(omitText, linePrefix = "SMTP <<< "))
+            Log.v("%s", smtpResponse.toLogString(omitText, linePrefix = "SMTP <<< "))
         }
     }
 
@@ -269,7 +271,7 @@ class SmtpTransport(
                 largestAcceptableMessage = size
             } else {
                 if (K9MailLib.isDebug() && K9MailLib.DEBUG_PROTOCOL_SMTP) {
-                    Timber.d("SIZE parameter is not a valid integer: %s", sizeParameter)
+                    Log.d("SIZE parameter is not a valid integer: %s", sizeParameter)
                 }
             }
         }
@@ -297,13 +299,13 @@ class SmtpTransport(
             helloResponse.keywords
         } else {
             if (K9MailLib.isDebug()) {
-                Timber.v("Server doesn't support the EHLO command. Trying HELO...")
+                Log.v("Server doesn't support the EHLO command. Trying HELO...")
             }
 
             try {
                 executeCommand("HELO %s", host)
             } catch (e: NegativeSmtpReplyException) {
-                Timber.w("Server doesn't support the HELO command. Continuing anyway.")
+                Log.w("Server doesn't support the HELO command. Continuing anyway.")
             }
 
             emptyMap()
@@ -345,7 +347,12 @@ class SmtpTransport(
 
         var entireMessageSent = false
         try {
-            val mailFrom = constructSmtpMailFromCommand(message.from, is8bitEncodingAllowed)
+            val mailFrom =
+                constructSmtpMailFromCommand(
+                    message.from,
+                    is8bitEncodingAllowed,
+                    message.usesAnyUnicodeAddresses(),
+                )
             if (isPipeliningSupported) {
                 val pipelinedCommands = buildList {
                     add(mailFrom)
@@ -394,19 +401,20 @@ class SmtpTransport(
         }
     }
 
-    private fun constructSmtpMailFromCommand(from: Array<Address>, is8bitEncodingAllowed: Boolean): String {
+    private fun constructSmtpMailFromCommand(
+        from: Array<Address>,
+        is8bitEncodingAllowed: Boolean,
+        canUseSmtputf8: Boolean,
+    ): String {
         val fromAddress = from.first().address
-        return if (is8bitEncodingAllowed) {
-            String.format("MAIL FROM:<%s> BODY=8BITMIME", fromAddress)
-        } else {
-            Timber.d("Server does not support 8-bit transfer encoding")
-            String.format("MAIL FROM:<%s>", fromAddress)
-        }
+        val smtputf8 = if (areUnicodeAddressesAllowed && canUseSmtputf8) " SMTPUTF8" else ""
+        val eightbit = if (is8bitEncodingAllowed) " BODY=8BITMIME" else ""
+        return String.format(Locale.US, "MAIL FROM:<%s>%s%s", fromAddress, smtputf8, eightbit)
     }
 
     private fun ensureClosed() {
         if (inputStream != null || outputStream != null || socket != null || responseParser != null) {
-            Timber.w(RuntimeException(), "SmtpTransport was open when it was expected to be closed")
+            Log.w(RuntimeException(), "SmtpTransport was open when it was expected to be closed")
             close()
         }
     }
@@ -439,7 +447,7 @@ class SmtpTransport(
             } else {
                 "SMTP >>> $command"
             }
-            Timber.d(commandToLog)
+            Log.d(commandToLog)
         }
 
         // Important: Send command + CRLF using just one write() call. Using multiple calls might result in multiple
@@ -541,7 +549,7 @@ class SmtpTransport(
     }
 
     private fun saslOAuth(method: OAuthMethod) {
-        Timber.d("saslOAuth() called with: method = $method")
+        Log.d("saslOAuth() called with: method = $method")
         retryOAuthWithNewToken = true
 
         val primaryEmail = oauthTokenProvider?.primaryEmail
@@ -550,7 +558,7 @@ class SmtpTransport(
         try {
             attempOAuth(method, primaryUsername)
         } catch (negativeResponse: NegativeSmtpReplyException) {
-            Timber.w(negativeResponse, "saslOAuth: failed to authenticate.")
+            Log.w(negativeResponse, "saslOAuth: failed to authenticate.")
             if (negativeResponse.replyCode != SMTP_AUTHENTICATION_FAILURE_ERROR_CODE) {
                 throw negativeResponse
             }
@@ -583,7 +591,7 @@ class SmtpTransport(
     ) {
         // Token was invalid. We could avoid this double check if we had a reasonable chance of knowing if a token was
         // invalid before use (e.g. due to expiry). But we don't. This is the intended behaviour per AccountManager.
-        Timber.v(negativeResponseFromOldToken, "Authentication exception, re-trying with new token")
+        Log.v(negativeResponseFromOldToken, "Authentication exception, re-trying with new token")
 
         try {
             attempOAuth(method, username)
@@ -593,7 +601,7 @@ class SmtpTransport(
             }
 
             // Okay, we failed on a new token. Invalidate the token anyway but assume it's permanent.
-            Timber.v(negativeResponseFromNewToken, "Authentication exception for new token, permanent error assumed")
+            Log.v(negativeResponseFromNewToken, "Authentication exception for new token, permanent error assumed")
 
             oauthTokenProvider!!.invalidateToken()
             handlePermanentOAuthFailure(method, negativeResponseFromNewToken)
@@ -641,7 +649,7 @@ class SmtpTransport(
         try {
             open()
         } catch (e: Exception) {
-            Timber.e(e, "Error while checking server settings")
+            Log.e(e, "Error while checking server settings")
             throw e
         } finally {
             close()
