@@ -22,6 +22,9 @@ import com.fsck.k9.mail.testing.XOAuth2ChallengeParserTestData
 import com.fsck.k9.mail.testing.message.TestMessageBuilder
 import com.fsck.k9.mail.testing.security.TestTrustedSocketFactory
 import com.fsck.k9.mail.transport.mockServer.MockSmtpServer
+import net.thunderbird.core.logging.legacy.Log
+import net.thunderbird.core.logging.testing.TestLogger
+import org.junit.Before
 import org.junit.Test
 import org.mockito.ArgumentMatchers.anyLong
 import org.mockito.kotlin.doReturn
@@ -38,6 +41,11 @@ class SmtpTransportTest {
     private val socketFactory = TestTrustedSocketFactory
     private val oAuth2TokenProvider = createMockOAuth2TokenProvider()
 
+    @Before
+    fun setUp() {
+        Log.logger = TestLogger()
+    }
+
     @Test
     fun `open() should issue EHLO command`() {
         val server = MockSmtpServer().apply {
@@ -678,6 +686,61 @@ class SmtpTransportTest {
         server.verifyInteractionCompleted()
     }
 
+    @Test
+    fun `sendMessage() with unicode recipient and supporting server`() {
+        val message = createMessageWithUnicodeRecipient()
+        val server = createServerAndSetupForPlainAuthentication("SMTPUTF8").apply {
+            expect("MAIL FROM:<user@localhost> SMTPUTF8")
+            output("250 OK")
+            expect("RCPT TO:<user2@dømi.example>")
+            output("250 OK")
+            expect("DATA")
+            output("354 End data with <CR><LF>.<CR><LF>")
+            expect("[message data]")
+            expect(".")
+            output("250 OK: queued as 12345")
+            expect("QUIT")
+            output("221 BYE")
+            closeConnection()
+        }
+        val transport = startServerAndCreateSmtpTransport(server)
+
+        transport.sendMessage(message)
+
+        server.verifyConnectionClosed()
+        server.verifyInteractionCompleted()
+    }
+
+    @Test
+    fun `sendMessage() with unicode recipient and plain server`() {
+        val message = createMessageWithUnicodeRecipient()
+        val server = createServerAndSetupForPlainAuthentication("8BITMIME").apply {
+            expect("MAIL FROM:<user@localhost> BODY=8BITMIME")
+            output("250 OK")
+            // Many servers reject this as nonstandard, but some
+            // accept it. The purpose of this commit is to change the
+            // behaviour when SMTPUTF8 is supported. Therefore this
+            // test checks that Thunderbird behaves as previously when
+            // the server does not support SMTPUTF8.
+            expect("RCPT TO:<user2@dømi.example>")
+            output("250 OK")
+            expect("DATA")
+            output("354 End data with <CR><LF>.<CR><LF>")
+            expect("[message data]")
+            expect(".")
+            output("250 OK: queued as 12345")
+            expect("QUIT")
+            output("221 BYE")
+            closeConnection()
+        }
+        val transport = startServerAndCreateSmtpTransport(server)
+
+        transport.sendMessage(message)
+
+        server.verifyConnectionClosed()
+        server.verifyInteractionCompleted()
+    }
+
     @Test
     fun `sendMessage() with message too large should throw`() {
         val message = createDefaultMessageBuilder()
@@ -929,6 +992,13 @@ class SmtpTransportTest {
             .build()
     }
 
+    private fun createMessageWithUnicodeRecipient(): Message {
+        return TestMessageBuilder()
+            .from("user@localhost")
+            .to("user2@dømi.example")
+            .build()
+    }
+
     private fun createServerAndSetupForPlainAuthentication(vararg extensions: String): MockSmtpServer {
         return MockSmtpServer().apply {
             output("220 localhost Simple Mail Transfer Service Ready")
